@@ -355,106 +355,6 @@ class MlflowXGBoostLint(TemplateLinter, metaclass=GetLintingFunctionsMeta):
         verify_method_not_present(self, all_reduce_functions, 'mlflow-xgboost-4')
 
 
-class MlflowXGBoostDaskLint(TemplateLinter, metaclass=GetLintingFunctionsMeta):
-    def __init__(self, path):
-        super().__init__(path)
-
-    def lint(self):
-        super().lint_project(self, self.methods)
-
-    def xgboost_dask_files_exist(self) -> None:
-        """
-        Checks a given project directory for required files.
-        Iterates through the templates's directory content and checkmarks files for presence.
-        Files that **must** be present::
-            'MLproject',
-            'environment.yml',
-            'project_slug/mlf_core/mlf_core.py'
-        Files that *should* be present::
-            '.github/workflows/train_cpu.yml',
-            '.github/workflows/lint.yml',
-        Files that *must not* be present::
-            none
-        Files that *should not* be present::
-            '__pycache__'
-        """
-
-        # NB: Should all be files, not directories
-        # List of lists. Passes if any of the files in the sublist are found.
-        files_fail = [
-            ['MLproject'],
-            ['environment.yml'],
-            [f'{self.project_slug_no_hyphen}/mlf_core/mlf_core.py']
-        ]
-        files_warn = [
-            [os.path.join('.github', 'workflows', 'train_cpu.yml')],
-            [os.path.join('.github', 'workflows', 'lint.yml')],
-        ]
-
-        # List of strings. Fails / warns if any of the strings exist.
-        files_fail_ifexists = [
-            '__pycache__'
-        ]
-        files_warn_ifexists = [
-
-        ]
-
-        files_exist_linting(self, files_fail, files_fail_ifexists, files_warn, files_warn_ifexists, handle='mlflow-xgboost_dask')
-
-    def xgboost_dask_reproducibility_seeds(self) -> None:
-        """
-        Verifies that all CPU and GPU reproducibility settings for XGBoost are enabled
-        """
-        passed_xgboost_dask_reproducibility_seeds = True
-        entry_point_file_path = f'{self.path}/{self.project_slug_no_hyphen}/{self.project_slug_no_hyphen}.py'
-        with open(entry_point_file_path) as f:
-            project_slug_entry_point_content = list(map(lambda line: line.strip(), f.readlines()))
-
-        expected_lines_xgboost_dask_reproducibility = ['MLFCore.set_general_random_seeds(dict_args["general_seed"])',
-                                                       'MLFCore.set_xgboost_dask_random_seeds(dict_args["xgboost_seed"], param)']
-
-        for expected_line in expected_lines_xgboost_dask_reproducibility:
-            if expected_line not in project_slug_entry_point_content:
-                passed_xgboost_dask_reproducibility_seeds = False
-                self.failed.append(('mlflow-xgboost_dask-2', f'{expected_line} not found in {entry_point_file_path}'))
-
-        if passed_xgboost_dask_reproducibility_seeds:
-            self.passed.append(('mlflow-xgboost_dask-2', 'All required reproducibility settings enabled.'))
-
-    def xgboost_version(self) -> None:
-        """
-        Verifies that the XGBoost version is at least 1.1.0, since reproducibility cannot be guaranteed elsewise.
-        """
-        # Verify that XGBoost version is greater than 1.1.0
-        conda_env = load_yaml_file(f'{self.path}/environment.yml')
-        conda_only = list(filter(lambda dep: '::' in dep, conda_env['dependencies']))
-        pip_only = list(filter(lambda dep: isinstance(dep, dict), conda_env['dependencies']))[0]['pip']
-
-        for dependency in conda_only:
-            if 'xgboost' in dependency:
-                split = dependency.split('==')
-                current_version = parse_version(split[-1])
-                if current_version < parse_version('1.1.0'):
-                    self.failed.append(('mlflow-xgboost_dask-3',
-                                        f'XGBoost version {current_version} is not at least 1.1.0. Reproducibility cannot be guaranteed.'))
-
-        for dependency in pip_only:
-            if 'xgboost' in dependency:
-                split = dependency.split('==')
-                current_version = parse_version(split[-1])
-                if current_version < parse_version('1.1.0'):
-                    self.failed.append(('mlflow-xgboost_dask-3',
-                                        f'XGBoost version {current_version} is not at least 1.1.0. Reproducibility cannot be guaranteed.'))
-
-    def xgboost_no_all_reduce(self) -> None:
-        """
-        Verifies that all_reduce is not used.
-        https://github.com/dmlc/xgboost/issues/5023
-        """
-        all_reduce_functions = ['all_reduce']
-        verify_method_not_present(self, all_reduce_functions, 'mlflow-xgboost-4')
-
-
 def verify_method_not_present(calling_class: TemplateLinter, functions_to_check: list, linting_code: str):
     """
     Checks all Python files for a list of strings/functions, which should not be present.
@@ -466,7 +366,7 @@ def verify_method_not_present(calling_class: TemplateLinter, functions_to_check:
     for root, dirs, files in os.walk(f'{calling_class.path}/{calling_class.project_slug_no_hyphen}'):
         for file in files:
             if file.endswith(".py"):
-                file_to_check_full_path = Path(root)/file
+                file_to_check_full_path = Path(root) / file
                 with open(file_to_check_full_path) as f:
                     content_stripped = list(map(lambda line: line.strip(), f.readlines()))
                     for function in functions_to_check:
